@@ -108,6 +108,16 @@ target_patternview_meta.tar_branch <- function(target, pipeline, meta) {
   patternview_register_meta(parent$patternview, record)
 }
 
+#' @export
+target_patternview_started.tar_branch <- function(
+  target,
+  pipeline,
+  scheduler
+) {
+  parent <- pipeline_get_target(pipeline, target_get_parent(target))
+  patternview_register_started(parent$patternview, parent, scheduler)
+}
+
 #' @export
 target_patternview_canceled.tar_branch <- function(
   target,
