@@ -75,12 +75,12 @@ tar_target_raw <- function(
     "library in tar_target_raw() must be NULL or character."
   )
   assert_format(format)
-  iteration <- match.arg(iteration, c("vector", "list", "group"))
-  error <- match.arg(error, c("stop", "continue", "workspace"))
-  memory <- match.arg(memory, c("persistent", "transient"))
+  assert_flag(iteration, c("vector", "list", "group"))
+  assert_flag(error, c("stop", "continue", "workspace"))
+  assert_flag(memory, c("persistent", "transient"))
   assert_lgl(garbage_collection, "garbage_collection must be logical.")
   assert_scalar(garbage_collection, "garbage_collection must be a scalar.")
-  deployment <- match.arg(deployment, c("worker", "main"))
+  assert_flag(deployment, c("worker", "main"))
   assert_dbl(priority)
   assert_scalar(priority)
   assert_ge(priority, 0)
@@ -89,8 +89,8 @@ tar_target_raw <- function(
     resources,
     "resources in tar_target_raw() must be a named list."
   )
-  storage <- match.arg(storage, c("main", "worker"))
-  retrieval <- match.arg(retrieval, c("main", "worker"))
+  assert_flag(storage, c("main", "worker"))
+  assert_flag(retrieval, c("main", "worker"))
   if (!is.null(cue)) {
     cue_validate(cue)
   }
